(function(){var a={}.hasOwnProperty,b=function(f,d){for(var c in d){if(a.call(d,c)){f[c]=d[c]}}function e(){this.constructor=f}e.prototype=d.prototype;f.prototype=new e();f.__super__=d.prototype;return f};window.Controls.bind__template=(function(d){b(c,d);function c(){return c.__super__.constructor.apply(this,arguments)}c.prototype.append=function(e){this.dom=e.dom;if(!this.properties.visible&&this.dom){$(this.dom).hide()}this.properties=e.properties;return this.children.push(e)};return c})(window.Control)}).call(this);