.control {
	&.dialog {
		position: fixed;
		left: 0;
		top: 0;
		width: 100%;
		height: 100%;
		overflow: auto;
		z-index: 100;

		&>.backdrop {
			background: rgba(0,0,0,0.7);
			width: 100%;
			height: 100%;
			overflow-x: hidden;
			overflow-y: auto;

			&>.content {
				width: 400px;
				margin: 60px auto;

				background: #fbfbfb;
				.border-radius(5px);
				.box-shadow(@mainPaneShadow);
				overflow: hidden;

				&>.buttons {
					>* {
						float:right;
					}

					padding: 8px 10px;
					overflow: hidden;
					border-top: 1px solid @toolbarGradient2;
					.box-shadow(0 1px 0 lighten(@toolbarGradient1, 5%) inset);
					#gradient > .vertical(@toolbarGradient1, @toolbarGradient2);
				}
			}
		}

	}
}