(function(){var a={}.hasOwnProperty,b=function(f,d){for(var c in d){if(a.call(d,c)){f[c]=d[c]}}function e(){this.constructor=f}e.prototype=d.prototype;f.prototype=new e();f.__super__=d.prototype;return f};window.Controls.main__page=(function(c){b(d,c);function d(){return d.__super__.constructor.apply(this,arguments)}d.prototype.createDom=function(){this.dom=$('<div class="control container main-page"> \n    <div class="content-wr">\n        <div class="content">\n            <div class="--child-container"></div>\n        </div>\n    </div>\n</div>');return this.childContainer=this.dom.find(".--child-container")};return d})(window.Control);window.Controls.main__sections_tab=(function(d){b(c,d);function c(){return c.__super__.constructor.apply(this,arguments)}c.prototype.createDom=function(){return this.dom=$$('<a href="#" class="tab '+(this.properties.active?"active":"")+'">\n    <i class="loader pull-right hide-when-loaded icon icon-spinner icon-spin"></i>\n    <i class="icon-'+this.properties.icon+'"></i>&nbsp;'+this.properties.title+"\n</a>")};return c})(window.Control);window.Controls.main__sections_category=(function(d){b(c,d);function c(){return c.__super__.constructor.apply(this,arguments)}c.prototype.createDom=function(){this.dom=$('<div class="control container main-sections-category"> \n    <div>'+this.properties.name+'</div>\n    <div class="content">\n        <div class="--child-container"></div>\n    </div>\n</div>');return this.childContainer=this.dom.find(".--child-container")};return c})(window.Control);window.Controls.main__sections_root=(function(d){b(c,d);function c(){return c.__super__.constructor.apply(this,arguments)}c.prototype.createDom=function(){this.dom=$('<div class="control container main-sections-root">\n    <div class="sidebar">\n        <div class="--tabs-container"></div>\n    </div>\n    <div class="main">\n        <div class="--child-container"></div>\n        <div class="no-sections">\n            <div>\n                <div class="control label bold">No plugins are allowed for this user</div>\n            </div>\n            <div>\n                <div class="control label">\n                    Please ask your administrator to go to Configuration plugin and give you permissions to access some plugins.\n                </div>\n            </div>\n        </div>\n    </div>\n</div>');this.tabsContainer=this.dom.find(".--tabs-container");this.childContainer=this.dom.find(".--child-container");this.categories={};if(!this.properties.is_empty){return this.dom.find(".no-sections").hide()}};c.prototype.append=function(h){var e,f,g=this;if(!this.categories[h.properties.category]){e=new Controls.main__sections_category(this.ui,{name:h.properties.category});this.categories[h.properties.category]=e;this.tabsContainer.append(e.dom)}f=new Controls.main__sections_tab(this.ui,$.extend(h.properties,{visible:true}));$(f.dom).click(function(i){$(f.dom).find(".loader").show();Feedback.emit("Section activated",{Class:h.properties.clsname,Name:h.properties.title});g.event("switch",{uid:h.uid});return i.preventDefault()});this.categories[h.properties.category].append(f);return c.__super__.append.call(this,h)};return c})(window.Control);window.Controls.main__section=(function(c){b(d,c);function d(){return d.__super__.constructor.apply(this,arguments)}d.prototype.createDom=function(){this.dom=$('<div class="control container section '+(this.properties.active?"active":"")+" "+(this.properties.plain?"plain":"normal")+'"">\n    <div class="--child-container"></div>\n</div>');return this.childContainer=this.dom.find(".--child-container")};return d})(window.Control);window.Controls.body=(function(d){b(c,d);function c(){return c.__super__.constructor.apply(this,arguments)}c.prototype.createDom=function(){this.dom=$$('<div class="control container section-body">\n</div>');return this.childContainer=this.dom};return c})(window.Control)}).call(this);