html.mode-tablet {
    #header .container {
    //    margin: 0;
    }

    .control.main-sections-root > .sidebar .tab {
        padding: 5px 10px;
        font-size: 12px;
        margin: 0;
        border-radius: 3px;
    }

    .control.main-page > .content-wr > .content {
    //    margin: 0 0 60px;
    }
}