(function(){var a={}.hasOwnProperty,b=function(f,d){for(var c in d){if(a.call(d,c)){f[c]=d[c]}}function e(){this.constructor=f}e.prototype=d.prototype;f.prototype=new e();f.__super__=d.prototype;return f};window.Controls.munin__plot=(function(d){b(c,d);function c(){return c.__super__.constructor.apply(this,arguments)}c.prototype.createDom=function(){var e,f=this;e="/ajenti:munin-proxy/"+encodeURIComponent(this.properties.url);if(this.properties.period){e+=this.properties.period+".png"}this.dom=$('<div class="control munin-plot '+(this.properties.widget?"widget-mode":"")+'">\n    <img src="'+e+'" />\n    <a href="#" class="control button style-normal"><i class="icon-plus"></i> Add widget</a>\n</div>');return this.dom.find("a").click(function(){return f.event("widget",{url:f.properties.url,period:f.properties.period})})};return c})(window.Control)}).call(this);